/**
 * @file
 * Javascript functionality for FBC custom theme.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.componentWrapperItems = Drupal.componentWrapperItems || {};
  Drupal.componentWrapperItems.isSetAccordion = false;
  Drupal.componentWrapperItems.isSetSlides = false;
  Drupal.componentWrapperItems.defaultHeightNavigationToId = 0;
  Drupal.componentWrapperItems.isUpdateCarousel = false;
  Drupal.componentWrapperItems.isSetEventMenu = false;
  Drupal.behaviors.romanbathsBehavior = {
    attach: function (context) {
      Drupal.componentWrapperItems.sitePickerCollapse(context);
      Drupal.componentWrapperItems.menuEvents(context);
      Drupal.componentWrapperItems.collapseAlert(context);

      Drupal.componentWrapperItems.carouselImages(context);


      $(document).ready(function () {
        Drupal.componentWrapperItems.windowEvents();
        Drupal.componentWrapperItems.collapseSearch();
        Drupal.componentWrapperItems.menuSubItem();
        Drupal.componentWrapperItems.menuMobile();

        Drupal.componentWrapperItems.componentsJs();
        Drupal.componentWrapperItems.siteCustomJs();
      });

      Drupal.componentWrapperItems.componentsCustomJs(context);
    }
  }

  Drupal.componentWrapperItems.sitePickerCollapse = function (context) {
    var $sitePicker = $('#block-sitechooser-3 .site-chooser-tab, #block-sitechooser-2 .site-chooser-tab', context).once('iconIosArrowUp');
    if ($sitePicker.length > 0) {
      $sitePicker.click(function () {
        var $this = $(this);
        var $icon = $this.find('.ion-ios7-arrow-up');
        if ($icon.hasClass('open')) {
          $icon.removeClass('open');
          $('.view-id-site_picker.view-display-id-block_2').slideUp();
        } else {
          $icon.addClass('open');
          $('.view-id-site_picker.view-display-id-block_2').slideDown();
        }
      });
    }
  }

  Drupal.componentWrapperItems.collapseAlert = function (context) {
    const $btnAlert = $('.btn-close-alert', context).once('toggleBodyAlert');
    if ($btnAlert.length) {
      var sessionStatus = sessionStorage.getItem('closeAlert');
      if (sessionStatus && sessionStatus == 1) {
        $('.wrapper-alert').css({'display': 'none'});
      } else {
        $btnAlert.click(function () {
          $('.wrapper-alert').slideUp('fast');
          sessionStorage.setItem('closeAlert', 1);
        });
      }
    }
  }

  Drupal.componentWrapperItems.collapseSearch = function () {
    $('.btn--search-input-custom').once('toggleSearchInput').click(function () {
      Drupal.componentWrapperItems.resetHeaderMenu();
      $(this).toggleClass('open')
      $('#block-exposedformsite-searchpage-1').toggle('open');
      $('body').toggleClass('show-input-search');
    })
  }

  Drupal.componentWrapperItems.menuEvents = function (context) {
    var $header_menu = $('[data-level=0][class*="header-background"]', context).once('menu-item-romanbaths');
    if ($header_menu.length > 0) {
      $header_menu.removeClass('active active-trail');
    }
    if ($header_menu.length > 0) {
      $header_menu.click(function (e) {
        var $this = $(this);
        const classBackground = $this.attr('data-class');
        var classesBackground = 'header-background-blue header-background-purple header-background-black header-background-red';
        $this.siblings(".we-mega-menu-li[data-level=0]").removeClass('header-background-active');
        if (screen.width > 991) {
          if ($this.hasClass('header-background-active')) {
            $('body').removeClass(classesBackground);
          } else {
            $('body').removeClass(classesBackground.replaceAll(classBackground, '').trim());
            $('body').addClass(classBackground);
          }
          $this.toggleClass('header-background-active');
          // $(this).children('div.we-mega-menu-submenu').toggleClass('active-menu-item');
        }

        if ($('.btn--search-input-custom').hasClass('open')) {
          $('.btn--search-input-custom').removeClass('open')
          $('#block-exposedformsite-searchpage-1').toggle();
          $('body').toggleClass('show-input-search');
        }
        e.stopPropagation();
        e.preventDefault();
      })
    }
  }

  Drupal.componentWrapperItems.menuSubItem = function () {
    $('.we-mega-menu-submenu .we-mega-menu-li').once('clickMenuItem').click(function (e) {
      e.stopPropagation();
    })
    $('#block-bathmainnavigation ul > li.we-mega-menu-li.header-background-blue').once('clickHeaderMenuItem').click(function (e) {
      e.stopPropagation();
    })
  }

  Drupal.componentWrapperItems.menuMobile = function () {
    if ($(window).height() <= 991) {
      const $viewIdSitePicker = $('.view-id-site_picker.view-display-id-block_2').once('viewIdSitePicker');
      if ($viewIdSitePicker.length > 0) {
        let toolbarHeight = $('#toolbar-bar').outerHeight() || 0;
        let maxHeight = 50.5 + toolbarHeight;
        $viewIdSitePicker.css({'max-height': `calc(100vh - ${maxHeight}px)`});
      }
    }
  }

  Drupal.componentWrapperItems.resetHeaderMenu = function () {
    var $body = $('body');
    if ($body.hasClass('header-background-blue')) {
      $body.removeClass('header-background-blue')
    }
    $('.header-background-blue div.we-mega-menu-submenu').each(function () {
      if ($(this).hasClass('active-menu-item')) {
        $(this).removeClass('active-menu-item');
      }
    })

    $('.header-background-blue').removeClass('header-background-blue-active');

  }

  Drupal.componentWrapperItems.windowEvents = function () {
    $(window).once('windowClickEvent').click(function () {
      $('body').removeClass('header-background-blue header-background-purple header-background-black header-background-red');
      $('.header-background-blue, .we-mega-menu-li[data-level=0]').removeClass('header-background-blue-active header-background-active');
      // $('.we-mega-menu-li[data-level=0]').removeClass('header-background-active');
    });
  }

  Drupal.componentWrapperItems.componentsJs = function () {
    Drupal.componentWrapperItems.navigationToID();
    Drupal.componentWrapperItems.imageDivider();
    Drupal.componentWrapperItems.imageAndInfo();
    Drupal.componentWrapperItems.bannerGrid();
    Drupal.componentWrapperItems.anchorMenu();
    Drupal.componentWrapperItems.caseStudy();
  }

  Drupal.componentWrapperItems.componentsCustomJs = function (context) {
    Drupal.componentWrapperItems.accordion(context);
  }

  Drupal.componentWrapperItems.faq = function (context) {
    var $faqs = $('.component-faq', context).once('faqEvents');
    if ($faqs.length > 0) {
      $faqs.each(function () {
        const $this = $(this);
        var $field_items = $this.find('.field__items');
        $field_items.each(function () {
          const $thisItems = $(this);
          let $title_collapse = $thisItems.find('.group-title');
          let $accordion_content = $thisItems.find('.group-body');
          $title_collapse.click(function () {
            $title_collapse.toggleClass('component-faq--show');
            $accordion_content.slideToggle(300);
          });
        })
      })
    }
  }

  Drupal.componentWrapperItems.carouselImages = function (context) {
    var $carousels = $('.component-builder-wrapper.component-wrapper--carousel', context).once('wrapperCarousel');
    if ($carousels.length > 0) {
      $carousels.each(function () {
        var $this = $(this);
        const number = $this.attr('data-carousel-columns') || 2;
        var $items = $this.find('.component_wrapper__content > .field--name-field-carousel.field__items');
        Drupal.componentWrapperItems.carouselImageSlide($items, number);
      })
    }
  }


  Drupal.componentWrapperItems.siteCustomJs = function () {
    Drupal.componentWrapperItems.eventsBlockThree();
  }

  Drupal.componentWrapperItems.eventsBlockThree = function () {
    var $signing_up_icon = $('.btn--navigation-to-signing-up');
    if ($signing_up_icon.length > 0) {
      $signing_up_icon.attr('href', '#mailchimp-signup-subscribe-block-stay-updated-form');
    }
  }

  Drupal.componentWrapperItems.imageDivider = function () {
    $('.components-image-divider a.zoom').once('showInfoImage').click(function () {
      $(this).parents().find('.field--name-field-image-info').toggle();
    })
  }

  Drupal.componentWrapperItems.navigationToID = function () {
    Drupal.componentWrapperItems.detectNavigationToIdHeight();
    var $toolbar = $('#toolbar-administration');
    var toolbar_height = $toolbar.length > 0 ? 75 : 0;
    var $navigation_item = $('.components-navigation-to-id');
    if ($navigation_item.length > 0) {
      let $list_href = $navigation_item.find('a');
      $list_href.once('navigationItem').click(function (e) {
        var target_id = $(this).attr('href');
        $("html, body").scrollTop($(target_id).offset().top - Drupal.componentWrapperItems.defaultHeightNavigationToId - toolbar_height);
        e.preventDefault();
      })
      let offset_top = $navigation_item.offset().top;
      if ($(window).scrollTop > offset_top) {
        if ($(this).scrollTop() >= offset_top) {
          $navigation_item.addClass('sticky')
        } else {
          $navigation_item.removeClass('sticky')
        }
      }
      $(window).scroll(function () {
        if ($(this).scrollTop() >= offset_top) {
          $navigation_item.addClass('sticky')
        } else {
          $navigation_item.removeClass('sticky')
        }
      });
    }

    // custom button pre & next
    var $prev = $navigation_item.find('.prev');
    var let_of_pre_btn = $prev.css('left');
    if (let_of_pre_btn == '0px' || let_of_pre_btn == 'auto') {
      $prev.addClass('hidden-button');
    }
    var $next = $navigation_item.find('.next');
    var $wrapper = $navigation_item.find('.component-navigation-to-id--wrapper');
    if ($wrapper.length > 0) {
      let $title = $wrapper.children('.field-title');
      let title_width = 0;
      if ($title.length > 0) {
        title_width = $title.outerWidth();
      }
      var $target = '';
      if (title_width >= 0.4 * screen.width) {
        $navigation_item.addClass('title-block');
        $wrapper.addClass('title-block');
        $target = $wrapper.find('.field-items');
        var limit_left = 0;
        $navigation_item.find('.field-items .field-item').each(function () {
          limit_left += $(this).outerWidth(true);
        });

        limit_left -= $title.outerWidth();
      } else {
        $navigation_item.removeClass('title-block');
        $wrapper.removeClass('title-block');
        $target = $wrapper;
      }

      if ($target.length > 0) {
        var is_inline = 1;
        if (!$wrapper.hasClass('title-block')) {
          is_inline = 0;
          var allowed_left = $navigation_item.width() - $navigation_item.find('.navigation-to-id--wrapper-button').width();
          var width_of_items = 0;
          var width_of_title = $wrapper.find('.field-title').outerWidth();
          $wrapper.find('.field-items .field-item').each(function () {
            width_of_items += $(this).outerWidth(true);
          });
          limit_left = width_of_items * (1.05) + width_of_title - allowed_left;
        }

        $prev.once('clickPreNavigationToId').click(function () {
          let old_left = $target.attr('attr-left-value') || 0;
          old_left = parseInt(old_left);
          let new_left = old_left + 50;
          if (new_left > 0) {
            new_left = 0;
            $(this).addClass('hidden-button');
          } else {
            $(this).removeClass('hidden-button');
          }

          $next.removeClass('hidden-button');
          $target.attr('attr-left-value', new_left);
          $target.css({'left': new_left + '%'})
        })

        $next.once('clickPreNavigationToId').click(function () {
          let old_left = $target.attr('attr-left-value') || 0;
          old_left = parseInt(old_left);
          let new_left = old_left - 50;
          let new_left_px = parseInt($target.css('left').replaceAll('px', ''));
          if ((new_left_px + limit_left) < 0) {
            new_left = old_left;
            $(this).addClass('hidden-button');
          } else {
            $(this).removeClass('hidden-button');
          }

          $prev.removeClass('hidden-button');
          $target.attr('attr-left-value', new_left);
          $target.css({'left': new_left + '%'})
        })
      }
    }
  }

  Drupal.componentWrapperItems.imageAndInfo = function () {
    $('.components-image-and-info a.icon-show-image-info').once('showInfoImage').click(function () {
      $(this).parents().find('.field-name-field-image-info').toggle();
    })
  }

  Drupal.componentWrapperItems.bannerGrid = function () {
    $('.components-banner-grid a.icon-show-image-info').once('showInfoImageGrid').click(function () {
      $(this).parents().find('.field-name-field-image-info').toggle();
    })
  }

  Drupal.componentWrapperItems.setPositionButtonCarousel = function () {
    var $carousel = $('.components-carousel-images-3-col');
    if ($carousel.length > 0 && !Drupal.componentWrapperItems.isUpdateCarousel) {
      $carousel.each(function () {
        var $prev = $(this).find('.slick-prev');
        var $next = $(this).find('.slick-next');
        if ($prev.length > 0 || $next.length > 0) {
          var $first_image = $(this).find('img');
          if ($first_image.length > 0) {
            var first_image_height = $($first_image[0]).outerHeight();
          }
          let parent_height = $(this).find('.field__items').outerHeight();
          if (first_image_height > 0 && parent_height > 0) {
            let top = ((first_image_height / 2 - $prev.outerHeight() / 2) / parent_height).toFixed(1) * 100;
            $prev.css({'top': top + '%'});
            $next.css({'top': top + '%'});
          }
        }
      });
      Drupal.componentWrapperItems.isUpdateCarousel = true;
    }
  }

  Drupal.componentWrapperItems.carouselImageSlide = function ($selector, numberShow = 2, showDot = false) {
    if ($selector.length > 0) {
      Drupal.componentWrapperItems.isSetSlides = true;
      if ($selector.find('.field__item').length <= numberShow) {
        showDot = false;
      }
      console.log(numberShow);
      console.log($selector);
      $selector.not('.slick-initialized').slick({
        dots: showDot,
        infinite: true,
        speed: 300,
        slidesToShow: numberShow,
        slidesToScroll: 1,
        responsive: [
          {
            breakpoint: 1024,
            settings: {
              slidesToShow: numberShow,
              slidesToScroll: 1,
              infinite: true,
              dots: showDot
            }
          },
          {
            breakpoint: 768,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          },
          {
            breakpoint: 480,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          }
        ]
      });
    }

    $(document).ready(function () {
      Drupal.componentWrapperItems.setPositionButtonCarousel();
    })
  }

  Drupal.componentWrapperItems.accordion = function (context) {
    const $accordion = $('.components-accordion', context).once('accordionItems');
    if ($accordion.length > 0) {
      $accordion.each(function () {
        var $this = $(this);
        const $title = $this.find('.title');
        const $content = $this.find('.component_item__content')
        $title.click(function (e) {
          $content.slideToggle(350);
          $this.toggleClass('component-accordion--item-show');
        })
      })
    }
  }

  Drupal.componentWrapperItems.detectNavigationToIdHeight = function () {
    var $component_navigation_to_id = $('.components-navigation-to-id');
    if ($component_navigation_to_id.length > 0) {
      let _clone_item = $($component_navigation_to_id[0].outerHTML);
      _clone_item.addClass('sticky');
      _clone_item.css({'display': 'none'});
      $('body').append(_clone_item);
      let margin_bottom = _clone_item.css('margin-bottom');
      if (margin_bottom) {
        margin_bottom = eval(margin_bottom.replaceAll('px', ''));
      }
      Drupal.componentWrapperItems.defaultHeightNavigationToId = _clone_item.outerHeight() + margin_bottom;
      _clone_item.remove();
    }
  }

  Drupal.componentWrapperItems.anchorMenu = function () {
    var $component = $('.components-anchor-menu');
    $component.each(function () {
      var $list_href = $(this).find('a');
      $list_href.once('anchorMenuNavigationToItem').click(function (e) {
        var target_id = $(this).attr('href');
        var $toolbar = $('#toolbar-administration');
        var toolbar_height = $toolbar.length > 0 ? 80 : 0;
        $("html, body").scrollTop($(target_id).offset().top - Drupal.componentWrapperItems.defaultHeightNavigationToId - toolbar_height);
        e.preventDefault();
      })
    })
  }

  Drupal.componentWrapperItems.caseStudy = function () {
    var $caseStudy = $('.components-case-study');
    $caseStudy.each(function () {
      var $parent_column = $(this).closest('aside');
      if ($parent_column.length > 0) {
        if (screen.width >= 768 && screen.width <= 991) {
          var attr_width = $parent_column.attr('attr-content-width')
          $parent_column.removeClass('col-md-' + attr_width);
          $parent_column.addClass('col-md-12');
        }
      }
    })
  }

})(jQuery, Drupal);
