<?php

namespace Drupal\component_builder;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Component builder helper service.
 */
class ComponentBuilderHelper implements ComponentBuilderHelperInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Create an ComponentBuilderHelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getFieldsReferencedComponent($entity_id = NULL) {
    $results = &drupal_static(__FUNCTION__);
    if (empty($results)) {
      $storage = $this->entityTypeManager->getStorage('field_storage_config');
      $entity_ids = $storage->getQuery()->execute();
      $field_storages = $storage->loadMultipleOverrideFree($entity_ids);
      foreach ($field_storages as $field_storage) {
        $field_storage_name = $field_storage->getName();
        $filed_storage_type = $field_storage->getType();
        if ($filed_storage_type === 'entity_reference') {
          $filed_storage_target_type = $field_storage->getSettings()['target_type'];
          if ($filed_storage_target_type === 'component_wrapper') {
            foreach ($field_storage->getBundles() as $bundle) {
              [$target_entity_id] = explode('.', $field_storage->id(), 2);
              $results[$target_entity_id][$bundle][$field_storage_name] = $field_storage;
            }
          }
        }
      }
    }

    return $entity_id && isset($results[$entity_id]) ? $results[$entity_id] : $results;
  }

}
