<?php

namespace Drupal\component_builder;

use Drupal\Core\Entity\EntityInterface;
use Drupal\entity\BulkFormEntityListBuilder;
use Drupal\component_builder\Entity\ComponentItemType;

/**
 * Defines the list builder for products.
 */
class ComponentItemListBuilder extends BulkFormEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['title'] = t('Title');
    $header['type'] = t('Type');
    $header['status'] = t('Status');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\component_builder\Entity\ComponentItemTypeInterface $item_type */
    $item_type = ComponentItemType::load($entity->bundle());
    if (!$item_type) {
      $entity->delete();
    }
    $row['title']['data'] = [
      '#type' => 'link',
      '#title' => $entity->label(),
    ] + $entity->toUrl()->toRenderArray();
    $row['type'] = [
      '#markup' => $item_type ? $item_type->label() : '',
    ];
    $row['status'] = [
      '#markup' => $entity->isPublished() ? $this->t('published') : $this->t('not published'),
    ];
    return $row + parent::buildRow($entity);
  }

}
