<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\ComponentBuilderBase;

/**
 * Provides 'Timeline' component.
 *
 * @ComponentBuilder(
 *   id = "timeline",
 *   label = @Translation("Timeline"),
 *   group = @Translation("General components"),
 *   template = "timeline",
 *   dependencies = {
 *      "video_embed_field": {
 *         "label" : "Video Embed Field",
 *         "url" : "https://www.drupal.org/project/video_embed_field"
 *       }
 *    }
 * )
 */
class Timeline extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath() {
    return $this->getComponentPath() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables) {
    if (isset($variables['elements']['#component_item'])) {
      $component_timeline = $variables['elements']['#component_item'];
      // Render Item Timeline Left.
      $timeline_item_left = $component_timeline->get('field_ti_left')->referencedEntities()[0];
      if ($timeline_item_left) {
        // Render icon.
        $timeline_item_left_field_ti_icon_view = $timeline_item_left->get('field_ti_icon')->view();
        $timeline_item_left_field_ti_icon_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_left']['field_ti_icon'] = $timeline_item_left_field_ti_icon_view;
        $field_type = $timeline_item_left->get('field_type')->getString();
        if ($field_type === "image") {
          // Render image.
          $timeline_item_left_field_ti_image_view = $timeline_item_left->get('field_ti_image')->view();
          $timeline_item_left_field_ti_image_view['#label_display'] = 'hidden';
          $variables['content']['timeline_item_left']['field_ti_image'] = $timeline_item_left_field_ti_image_view;
        }
        elseif ($field_type === "video") {
          // Render embed video.
          $timeline_item_left_field_ti_video_view = $timeline_item_left->get('field_ti_video')->view();
          $timeline_item_left_field_ti_video_view['#label_display'] = 'hidden';
          $variables['content']['timeline_item_left']['field_ti_video'] = $timeline_item_left_field_ti_video_view;
        }
        // Render title.
        $timeline_item_left_field_ti_title_view = $timeline_item_left->get('title')->view();
        $timeline_item_left_field_ti_title_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_left']['field_title'] = $timeline_item_left_field_ti_title_view;
        // Render body.
        $timeline_item_left_field_ti_body_view = $timeline_item_left->get('field_ti_body')->view();
        $timeline_item_left_field_ti_body_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_left']['field_ti_body'] = $timeline_item_left_field_ti_body_view;
        // Render link.
        $timeline_item_left_field_ti_link_view = $timeline_item_left->get('field_ti_link')->view();
        $timeline_item_left_field_ti_link_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_left']['field_ti_link'] = $timeline_item_left_field_ti_link_view;
      }

      // Render Item Timeline Right.
      $timeline_item_right = $component_timeline->get('field_ti_right')->referencedEntities()[0];
      if ($timeline_item_right) {
        // Render icon.
        $timeline_item_right_field_ti_icon_view = $timeline_item_right->get('field_ti_icon')->view();
        $timeline_item_right_field_ti_icon_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_right']['field_ti_icon'] = $timeline_item_right_field_ti_icon_view;
        $field_type = $timeline_item_right->get('field_type')->getString();
        if ($field_type === "image") {
          // Render image.
          $timeline_item_right_field_ti_image_view = $timeline_item_right->get('field_ti_image')->view();
          $timeline_item_right_field_ti_image_view['#label_display'] = 'hidden';
          $variables['content']['timeline_item_right']['field_ti_image'] = $timeline_item_right_field_ti_image_view;
        }
        elseif ($field_type === "video") {
          // Render embed video.
          $timeline_item_right_field_ti_video_view = $timeline_item_right->get('field_ti_video')->view();
          $timeline_item_right_field_ti_video_view['#label_display'] = 'hidden';
          $variables['content']['timeline_item_right']['field_ti_video'] = $timeline_item_right_field_ti_video_view;
        }
        // Render title.
        $timeline_item_right_field_ti_title_view = $timeline_item_right->get('title')->view();
        $timeline_item_right_field_ti_title_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_right']['field_title'] = $timeline_item_right_field_ti_title_view;
        // Render body.
        $timeline_item_right_field_ti_body_view = $timeline_item_right->get('field_ti_body')->view();
        $timeline_item_right_field_ti_body_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_right']['field_ti_body'] = $timeline_item_right_field_ti_body_view;
        // Render link.
        $timeline_item_right_field_ti_link_view = $timeline_item_right->get('field_ti_link')->view();
        $timeline_item_right_field_ti_link_view['#label_display'] = 'hidden';
        $variables['content']['timeline_item_right']['field_ti_link'] = $timeline_item_right_field_ti_link_view;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries() {
    return [
      'css' => [
        'theme' => [
          'components/component_timeline/assets/style.css' => [],
        ],
      ],
      "version" => "VERSION",
    ];
  }

}
