<?php

namespace Drupal\my_module\Plugin\ComponentBuilder;

use Drupal\component_builder\Annotation\ComponentBuilder;
use Drupal\component_builder\ComponentBuilderBase;

/**
 * Provides 'My Component Type' component.
 *
 * @ComponentBuilder(
 *   id = "my_component_type",
 *   label = @Translation("My Component Type"),
 *   group = @Translation("Custom"),
 *   template = "my_component_type",
 *   dependencies = {
 *      "block_field": {
 *         "label" : "Block field",
 *         "url" : "https://www.drupal.org/project/block_field"
 *       }
 *    },
 *   module = "my_module",
 * )
 */
class MyComponentType extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath(): string {
    return $this->getComponentPath() . '/component_' . $this->getPluginId() . '/templates';
  }


  /**
   * {@inheritdoc}
   */
  public function getComponentPath(): string {
    return $this->getModulePath('my_module') . '/components';
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(): array {
    return [
      'css' => [
        'theme' => [
          'components/component_my_component_type/assets/style.css' => []
        ]
      ],
      'js' => [
        'components/component_my_component_type/assets/style.js' => []
      ],
      "version" => "VERSION",
    ];
  }

}
